"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.loadLocaleMessages = exports.setI18nLanguage = void 0;
const vue_1 = require("vue");
const apalize_js_1 = require("apalize.js");
let application_id = "";
function Main(config) {
    setI18nLanguage(config.i18n);
    application_id = config.application_id;
    config.router.beforeEach((to, from, next) => __awaiter(this, void 0, void 0, function* () {
        yield loadLocaleMessages(config.i18n);
        setI18nLanguage(config.i18n);
        return next();
    }));
    // extend config.i18n.global.t function
    const t = config.i18n.global.t;
    config.i18n.global.t = (key, ...values) => {
        const translation = t(key, ...values);
        if (apalize)
            apalize.translate(key);
        return translation;
    };
}
exports.default = Main;
function setI18nLanguage(i18n) {
    const locale = i18n.global.locale.toString();
    const html_element = document === null || document === void 0 ? void 0 : document.querySelector('html');
    if (html_element) {
        html_element.setAttribute('lang', locale);
    }
}
exports.setI18nLanguage = setI18nLanguage;
let translations;
let apalize = null;
const loadApalize = () => __awaiter(void 0, void 0, void 0, function* () {
    apalize = yield (0, apalize_js_1.default)({
        application_id: application_id
    });
});
function loadLocaleMessages(i18n) {
    return __awaiter(this, void 0, void 0, function* () {
        const locale = i18n.global.locale.toString();
        if (!apalize) {
            yield loadApalize();
        }
        if (!translations) {
            translations = convertToVueI18n(apalize.translations);
        }
        i18n.global.setLocaleMessage(locale, translations[locale]);
        return (0, vue_1.nextTick)();
    });
}
exports.loadLocaleMessages = loadLocaleMessages;
const convertToVueI18n = (translations) => {
    const messages = {};
    translations.forEach(translation => {
        const values = translation.values;
        values.forEach(value => {
            if (!messages[value.locale]) {
                messages[value.locale] = {};
            }
            const keys = translation.key.split(".");
            let obj = messages[value.locale];
            for (let i = 0; i < keys.length; i++) {
                if (i === keys.length - 1) {
                    obj[keys[i]] = value.value;
                }
                else {
                    if (!obj[keys[i]]) {
                        obj[keys[i]] = {};
                    }
                    obj = obj[keys[i]];
                }
            }
        });
    });
    return messages;
};
